==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateFluent<A extends ResourceClaimTemplateFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimTemplateFluent.MetadataNested<A> editMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimTemplateSpec getSpec();
  public ResourceClaimTemplateSpec buildSpec();
  public A withSpec(ResourceClaimTemplateSpec spec);
  public Boolean hasSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> withNewSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> withNewSpecLike(ResourceClaimTemplateSpec item);
  public ResourceClaimTemplateFluent.SpecNested<A> editSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimTemplateSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimTemplateFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimTemplateSpecFluent<ResourceClaimTemplateFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateFluent<A extends ResourceClaimTemplateFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimTemplateFluent.MetadataNested<A> editMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimTemplateFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimTemplateSpec getSpec();
  public ResourceClaimTemplateSpec buildSpec();
  public A withSpec(ResourceClaimTemplateSpec spec);
  public Boolean hasSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> withNewSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> withNewSpecLike(ResourceClaimTemplateSpec item);
  public ResourceClaimTemplateFluent.SpecNested<A> editSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimTemplateFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimTemplateSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimTemplateFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimTemplateSpecFluent<ResourceClaimTemplateFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
